function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { StyleSheet, findNodeHandle, View, processColor } from 'react-native';
import { RNIPopoverView } from '../../native_components/RNIPopoverView';
import { RNIPopoverViewModule } from '../../native_modules/RNIPopoverViewModule';
import * as Helpers from '../../functions/helpers';
import { IS_PLATFORM_IOS } from '../../constants/LibEnv';
export class PopoverView extends React.PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "nativeRef", void 0);

    _defineProperty(this, "getProps", () => {
      const {
        popoverBackgroundColor,
        permittedArrowDirections,
        popoverSize,
        popoverShouldDismiss,
        popoverCanOverlapSourceViewRect,
        lazyPopover,
        renderPopoverContent,
        onPopoverDidHide,
        onPopoverWillShow,
        onPopoverWillHide,
        onPopoverDidShow,
        onPopoverDidHideViaTap,
        onPopoverWillHideViaTap,
        onPopoverDidAttemptToDismiss,
        ...viewProps
      } = this.props;
      return {
        // A. Provide default values to props...
        lazyPopover: lazyPopover !== null && lazyPopover !== void 0 ? lazyPopover : true,
        popoverShouldDismiss: popoverShouldDismiss !== null && popoverShouldDismiss !== void 0 ? popoverShouldDismiss : true,
        // B. Pass down props...
        popoverBackgroundColor,
        permittedArrowDirections,
        popoverSize,
        popoverCanOverlapSourceViewRect,
        renderPopoverContent,
        onPopoverDidHide,
        onPopoverWillShow,
        onPopoverWillHide,
        onPopoverDidShow,
        onPopoverDidHideViaTap,
        onPopoverWillHideViaTap,
        onPopoverDidAttemptToDismiss,
        // C. Move all the default view-related
        //    props here...
        viewProps
      };
    });

    _defineProperty(this, "setVisibility", async visibility => {
      const {
        lazyPopover
      } = this.getProps();
      if (!IS_PLATFORM_IOS) return;

      try {
        if (visibility) {
          await Promise.all([Helpers.setStateAsync(this, {
            mountPopover: true
          }), // temp bugfix: wait for popover to mount
          lazyPopover && Helpers.timeout(50)]);
        }

        ;
        await RNIPopoverViewModule.setVisibility(findNodeHandle(this.nativeRef), visibility);
      } catch (error) {
        if (__DEV__) {
          console.warn("PopoverView, setVisibility", error);
        }

        ;
        throw error;
      }

      ;
    });

    _defineProperty(this, "toggleVisibility", async () => {
      if (!IS_PLATFORM_IOS) return;
      const visibility = await this.getVisibility();
      await this.setVisibility(!visibility);
    });

    _defineProperty(this, "getVisibility", async () => {
      if (!IS_PLATFORM_IOS) return;
      return await RNIPopoverViewModule.getVisibility(findNodeHandle(this.nativeRef));
    });

    _defineProperty(this, "_handleOnPopoverDidHide", event => {
      var _this$props$onPopover, _this$props;

      (_this$props$onPopover = (_this$props = this.props).onPopoverDidHide) === null || _this$props$onPopover === void 0 ? void 0 : _this$props$onPopover.call(_this$props, event);
      Helpers.setStateAsync(this, {
        mountPopover: false
      });
    });

    this.state = {
      /** controls whether the popover content is mounted */
      mountPopover: false
    };
  }

  componentWillUnmount() {
    this.setVisibility(false);
  }

  //#endregion
  render() {
    var _props$renderPopoverC;

    const props = this.getProps();
    const {
      mountPopover
    } = this.state;
    return IS_PLATFORM_IOS ? /*#__PURE__*/React.createElement(RNIPopoverView, _extends({
      ref: r => {
        this.nativeRef = r;
      }
    }, props.viewProps, {
      // props
      popoverBackgroundColor: processColor(props.popoverBackgroundColor),
      permittedArrowDirections: props.permittedArrowDirections,
      popoverSize: props.popoverSize,
      popoverShouldDismiss: props.popoverShouldDismiss,
      popoverCanOverlapSourceViewRect: props.popoverCanOverlapSourceViewRect // events
      ,
      onPopoverWillShow: props.onPopoverWillShow,
      onPopoverWillHide: props.onPopoverWillHide,
      onPopoverDidShow: props.onPopoverDidShow,
      onPopoverDidHide: this._handleOnPopoverDidHide,
      onPopoverDidHideViaTap: props.onPopoverDidHideViaTap,
      onPopoverWillHideViaTap: props.onPopoverWillHideViaTap,
      onPopoverDidAttemptToDismiss: props.onPopoverDidAttemptToDismiss
    }), /*#__PURE__*/React.createElement(View, {
      style: styles.popoverContainer
    }, (mountPopover || !props.lazyPopover) && ((_props$renderPopoverC = props.renderPopoverContent) === null || _props$renderPopoverC === void 0 ? void 0 : _props$renderPopoverC.call(props))), this.props.children) : /*#__PURE__*/React.createElement(View, props.viewProps, this.props.children);
  }

}
;
const styles = StyleSheet.create({
  popoverContainer: {
    position: 'absolute',
    color: 'transparent'
  }
});
//# sourceMappingURL=PopoverView.js.map